#!/usr/bin/env node
"use strict";

var _yargs = _interopRequireDefault(require("yargs"));

var _simulate = require("./simulate");

var _server = _interopRequireDefault(require("@cardcore/server"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint-disable no-unused-expressions */
_yargs.default.command("server", "start a cardcore server", yargs => {
  yargs.option("port", {
    describe: `port to bind on`,
    default: 5000
  });
  yargs.option("data-dir", {
    describe: `data storage directory`,
    type: "string",
    default: null
  });
}, async argv => {
  await (0, _server.default)({
    port: argv.port,
    dataDir: argv.dataDir
  });
}).command("simulate", "run a simulation of a cardcore game", yargs => {
  yargs.option("count", {
    describe: "how many simulations to run",
    type: "number",
    default: 1
  });
  yargs.option("concurrency", {
    describe: "when count >= 1, how many simulations should I run at once?",
    type: "number",
    default: 16
  });
  yargs.command("create", "start up a cardcore client creating a game", yargs => {
    yargs.option("server", {
      describe: `server to which I should connect`,
      type: "string",
      demandOption: true
    });
  }, async argv => {
    await (0, _simulate.simulateCreate)(argv.server);
  });
  yargs.command("join", "start up a cardcore client creating a game", yargs => {
    yargs.option("server", {
      describe: `server to which I should connect`,
      type: "string",
      demandOption: true
    });
    yargs.option("game-id", {
      describe: "id of the simulated game",
      type: "string",
      demandOption: true
    });
  }, async argv => {
    await (0, _simulate.simulateJoin)(argv.server, argv.gameId);
  });
}, async argv => {
  await (0, _simulate.simulateServer)({
    count: argv.count,
    concurrency: argv.concurrency
  });
}).demandCommand().option("verbose", {
  alias: "v",
  default: false
}).argv;
//# sourceMappingURL=cardcore.js.map